function bool = checkERC(Phi,S,mode)
%function bool = checkERC(Phi,S,mode)
%==========================================================================                                                                         
%  FILE:           checkERC.m
%  AUTHOR:         Andreas Tillmann, TU Braunschweig, Germany                                         
%==========================================================================
%                                                                         
%  DESCRIPTION:    Check if the Exact Recovery Condition of J.Tropp is ful-
%                  filled. That is, if for Phi_S = (Phi(:,j))_{j in S} it
%                  holds that
%                  ERC = max{ ||PsInv*Phi(:,k)||_1 : k in SC } < 1.
%                                                                         
%  INPUT:   Phi    The matrix to be considered                    
%           S      The index set corresponding to vector support  
%           mode   A string argument specifying how the computations are  
%                  carried out; feasible values are     
%                  'lins' -> use linesolve, or CG if Phi is sparse
%                  'cg'   -> use CG (independent of sparsity of Phi)
%                  'pinv' -> use MATLAB's pinv-function or a modified ver-
%                            sion that can handle sparse matrix input 
%                            (output is dense)  
%                  [ optional; default is mode = 'pinv' ]             
%  OUTPUT:  bool   Indicator; has value 1/true, iff ERC(Phi,S)<1.                                                                       
%==========================================================================
% $Revision$
% $Author$
% $Date$
%==========================================================================
if( nargin < 3 )
    bool = (ERC(Phi,S,'pinv') < 1);
else
    bool = (ERC(Phi,S,mode) < 1);
end
