function bool = checkRIP(Phi,k,ca,rdm)
% function bool = checkRIP(Phi,k,ca,rdm)
% =========================================================================                                                                         
%  FILE:           checkRIP.m     
%  AUTHOR:         Andreas M. Tillmann, TU Braunschweig, Germany                               
% =========================================================================
%  DESCRIPTION:    Checks whether a given matrix Phi possesses the Restric-
%                  ted Isometry Property (RIP) (with some constant delta<1)
%                  for supports/column index subsets of sizes up to k.
%                  May also check the RIP condition approximately, based
%                  on computed lower bounds; see RIP_constant.m
%                  Typically, knowledge of the RIP constant is desired;
%                  in this case, consider using RIP_constant.m.
%                  Nevertheless, checkRIP can be used to confirm that RIP 
% 		           cannot hold for a given support size (when the returned 
%                  value is 0/false).
%
%  INPUT:   Phi    The matrix under consideration
%           k      The support size
%           ca     Indicator variable; pass ca=1 to check ALL support sets
%                  of size <= k, ca=0 to check only those with size == k
%                  [ optional; default is ca = 1 ]
%           rdm    Pass rdm=0 to check all support sets (size/s specified
%                  by ca), or a value >0 to check rdm-many random column
%                  index subsets
%                  [ optional; default is rdm = 0 ]
%
%  OUTPUT:  bool   Indicator; true iff for Phi and k an RIP constant was
%                  found (exact or approximate, depending on ca and rdm)
%                  which is smaller than 1, and false iff an index subset
%                  was found that violates the RIP condition for any con-
%                  stant smaller than 1.
% =========================================================================
% $Revision$
% $Author$
% $Date$
% =========================================================================
if( nargin < 3 )
    bool = (RIP_constant(Phi,k,1,0) < 1);
elseif( nargin < 4 )
    bool = (RIP_constant(Phi,k,ca,0) < 1);
else
    bool = (RIP_constant(Phi,k,ca,rdm) < 1);
end
